﻿Module Module1

    Sub Main()
        Dim nBarCodes As Integer
        Dim Path As String
        Dim i As Integer
        Dim nDirection As Integer
        Dim nPage As Integer
        Dim barcode As SoftekBarcodeNet.BarcodeReader

        ' The SoftekBarcodeNet component requires the following 2 DLL files, which have been included as items in this project (with copy to output directory enabled):
        ' SoftekBarcodeDLL.dll for 32-bit versions of windows
        ' SoftekBarcode64DLL.dll for 64-bit versions of windows.
        ' The SoftekBarcodeNet component handles the loading of the correct DLL.
        '
        ' The following 2 DLL files are also used if you are reading from PDF documents:
        ' 
        ' DebenuPDFLibraryDLLXXXX.dll
        ' DebenuPDFLibrary64DLLXXXX.dll
        '
        ' You can also create an instance of SoftekBarcodeNet using a path to the location of the DLL files
        ' e.g barcode = New SoftekBarcodeNet.BarcodeReader("/path/to/dll/files")

        barcode = New SoftekBarcodeNet.BarcodeReader("../../../../DLL")

        Using (barcode)
            ' Enter your license key here
            ' You can get a trial license key from sales@bardecode.com
            ' Example:
            ' barcode.LicenseKey = "MY LICENSE KEY"

            ' Turn on the barcode types you want to read.
            ' Turn off the barcode types you don't want to read (this will increase the speed of your application)
            barcode.ReadCode128 = True
            barcode.ReadCode39 = True
            barcode.ReadCode25 = True
            barcode.ReadEAN13 = True
            barcode.ReadEAN8 = True
            barcode.ReadUPCA = True
            barcode.ReadUPCE = True
            barcode.ReadCodabar = True
            barcode.ReadPDF417 = True
            barcode.ReadDataMatrix = True
            barcode.ReadDatabar = True
            barcode.ReadMicroPDF417 = False
            barcode.ReadQRCode = True

            ' Databar Options is a mask that controls which type of databar barcodes will be read and whether or not
            ' the software will look for a quiet zone around the barcode.
            ' 1 = 2D-Linkage flag (handle micro-PDf417 barcodes as supplementary data - requires ReadMicroPDF417 to be true).
            ' 2 = Read RSS14
            ' 4 = Read RSS14 Stacked
            ' 8 = Read Limited
            ' 16 = Read Expanded
            ' 32 = Read Expanded Stacked
            ' 64 = Require quiet zone
            barcode.DatabarOptions = 255

            ' If you want to read more than one barcode then set Multiple Read to 1
            ' Setting MutlipleRead to False will make the recognition faster
            barcode.MultipleRead = True

            ' Noise reduction takes longer but can make it possible to read some difficult barcodes
            ' When using noise reduction a typical value is 10 - the smaller the value the more effect it has.
            ' A zero value turns off noise reduction.
            ' barcode.NoiseReduction = 0

            ' You may need to set a small quiet zone if your barcodes are close to text and pictures in the image.
            ' A value of zero uses the default.
            barcode.QuietZoneSize = 0

            ' LineJump controls the frequency at which scan lines in an image are sampled.
            ' The default is 1.
            barcode.LineJump = 1

            ' You can restrict your search to a particular area of the image if you wish.
            ' This example limits the search to the upper half of the page
            ' Dim scanArea As System.Drawing.Rectangle
            ' scanArea = New System.Drawing.Rectangle(0, 0, 100, 50)
            ' barcode.SetScanRect(scanArea, 1)

            ' Set the direction that the barcode reader should scan for barcodes
            ' The value is a mask where 1 = Left to Right, 2 = Top to Bottom, 4 = Right To Left, 8 = Bottom to Top
            barcode.ScanDirection = 15

            ' Set the page number to read from in a multi-page TIF file. The default is 0, which will make the
            ' toolkit check every page.
            ' barcode.PageNo = 1

            ' DeskewMode controls the way in which the toolkit handles skewed documents. At the default level (2) 
            ' the toolkit will deskew at the main angle of the whole image. If the bar code is at a different angle
            ' to the rest of the image then try 3. For more complex images try values from 4 to 6.
            barcode.DeskewMode = 2

            ' ColorProcessingLevel controls how much time the toolkit will searching a color image for a barcode.
            ' The default value is 2 and the range of values is 0 to 5. If ColorThreshold is non-zero then 
            ' ColorProcessingLevel is effectively set to 0.
            barcode.ColorProcessingLevel = 2

            ' MaxLength and MinLength can be used to specify the number of characters you expect to
            ' find in a barcode. This can be useful to increase accuracy or if you wish to ignore some
            ' barcodes in an image.
            barcode.MinLength = 4
            barcode.MaxLength = 999

            ' When the toolkit scans an image it records the number of hits it gets for each barcode that
            ' MIGHT be in the image. If the hits recorded for any of the barcodes are >= PrefOccurrence
            ' then only these barcodes are returned. Otherwise, any barcode whose hits are >= MinOccurrence
            ' are reported. If you have a very poor quality image then try setting MinOccurrence to 1, but you
            ' may find that some false positive results are returned.
            ' barcode.MinOccurrence = 2
            ' barcode.PrefOccurrence = 4

            ' Read Code 39 barcodes in extended mode
            ' barcode.ExtendedCode39 = True

            ' Barcode string is numeric
            ' barcode.ReadNumeric = True

            ' Set a regular expression for the barcode
            ' barcode.Pattern = "^[A-Z]{2}[0-9]{5}$"

            ' If you are scanning at a high resolution and the spaces between bars are
            ' larger than 1 pixel then set MinSpaceBarWidth to 2 and increase your read rate.
            ' barcode.MinSpaceBarWidth = 2

            ' MedianFilter is a useful way to clean up higher resolution images where the black bars contain white dots
            ' and the spaces contain black dots. It does not work if the space between bars is only 1 pixel wide.
            barcode.MedianFilter = False

            ' Flags for handling PDF files
            ' PdfImageOnly defaults to true and indicates that the PDF documents are simple images.
            barcode.PdfImageOnly = True

            ' The PdfImageExtractOptions mask controls how images are removed from PDF documents (when PdfImageOnly is True)
            ' 1 = Enable fast extraction
            ' 2 = Auto-invert black and white images
            ' 4 = Auto-merge strips
            ' 8 = Auto-correct photometric values in black and white images
            barcode.PdfImageExtractOptions = 15

            ' The PdfImageRasterOptions mask controls how images are rasterized when PdfImageOnly is false or when image extraction fails
            ' 1 = Use alternative pdf-to-tif conversion function
            ' 2 = Always use pdf-to-tif conversion rather than loading the rasterized image directly into memory
            barcode.PdfImageRasterOptions = 0

            ' PdfDpi and PdfBpp control what sort of image the PDF document is rasterized into
            barcode.PdfDpi = 300
            barcode.PdfBpp = 8

            ' Or you can load the settings from a xml format file
            ' See the manual for more details.
            ' barcode.LoadXMLSettings("settings.xml")

            Path = "../../../../images/code39_01.tif"


            nBarCodes = barcode.ScanBarCode(Path)

            If nBarCodes <= -6 Then
                Console.WriteLine("License key error: either an evaluation key has expired or the license key is not valid for processing pdf documents")
            ElseIf nBarCodes < 0 Then
                Console.WriteLine("ScanBarCode returned error number " & nBarCodes)
                Console.WriteLine("Last Softek Error Number = " & barcode.GetLastError())
                Console.WriteLine("Last Windows Error Number = " & barcode.GetLastWinError())
            End If

            If nBarCodes = 0 Then
                Console.WriteLine("Sorry - no barcodes were found in this image")
            End If

            For i = 1 To nBarCodes
                Console.WriteLine("Barcode " & i & ":")

                Console.WriteLine("Value = " & barcode.GetBarString(i))

                Console.WriteLine("Type = " & barcode.GetBarStringType(i))

                Console.WriteLine("Quality Score = " & barcode.GetBarStringQualityScore(i) & "/5")

                nDirection = barcode.GetBarStringDirection(i)
                If nDirection = 1 Then
                    Console.WriteLine("Direction = Left to Right")
                Else
                    If nDirection = 2 Then
                        Console.WriteLine("Direction = Top to Bottom")
                    Else
                        If nDirection = 4 Then
                            Console.WriteLine("Direction = Right to Left")
                        Else
                            If nDirection = 8 Then
                                Console.WriteLine("Direction = Bottom to Top")
                            End If
                        End If
                    End If
                End If

                nPage = barcode.GetBarStringPage(i)
                Console.WriteLine("Page = " & nPage)
                Console.WriteLine("Top Left = (" & barcode.GetBarStringTlx(i) & "," & barcode.GetBarStringTly(i) & ")")
                Console.WriteLine("Bottom Right = (" & barcode.GetBarStringBrx(i) & "," & barcode.GetBarStringBry(i) & ")")
                Console.WriteLine("")

            Next i

        End Using

    End Sub

End Module
